@@ -65,12 +65,11 @@ pub trait CalcConsensus<'a, R: SequenceRead> {
             // new qual: (1 - MAP)
             let qual = (likelihoods[max_posterior] - marginal).ln_one_minus_exp();
             // Assume the maximal quality, if the likelihood is infinite
-            let truncated_quality: f64;
-            if (*PHREDProb::from(qual)).is_infinite() {
-                truncated_quality = 93.0;
+            let truncated_quality: f64 = if (*PHREDProb::from(qual)).is_infinite() {
+                93.0
             } else {
-                truncated_quality = *PHREDProb::from(qual);
-            }
+                *PHREDProb::from(qual)
+            };
             // Truncate quality values to PHRED+33 range
             consensus_qual
                 .push(cmp::min(93 + offset as u64, (truncated_quality + offset) as u64) as u8);
